=======================================================
networking-ovn - OpenStack Neutron integration with OVN
=======================================================

.. image:: https://governance.openstack.org/tc/badges/networking-ovn.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

OVN provides virtual networking for Open vSwitch and is a component of the
Open vSwitch project. This project provides integration between OpenStack
Neutron and OVN.

If you want to know about the key differences with ml2/ovs please have a look
on the FAQ (Frequently Asked Questions) section.

Contents
--------

.. toctree::
   :maxdepth: 2

   faq/index
   admin/index
   install/index
   install/migration
   configuration/index
   contributor/index

Links
-----
* Free software: Apache license
* Source: https://git.openstack.org/cgit/openstack/networking-ovn
* Bugs: https://bugs.launchpad.net/networking-ovn
* Mailing list:
  https://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev
* IRC: #openstack-neutron-ovn on Freenode.
* Docs: https://docs.openstack.org/networking-ovn/latest

.. rubric:: Indices and tables

* :ref:`genindex`
* :ref:`search`

